@@ -9,12 +9,17 @@ Usage::
         Client,
         DBInstanceAvailableWaiter,
         DBInstanceDeletedWaiter,
+        DescribeCertificatesPaginator,
+        DescribeDBClusterParameterGroupsPaginator,
+        DescribeDBClusterParametersPaginator,
+        DescribeDBClusterSnapshotsPaginator,
         DescribeDBClustersPaginator,
         DescribeDBEngineVersionsPaginator,
         DescribeDBInstancesPaginator,
         DescribeDBSubnetGroupsPaginator,
         DescribeEventsPaginator,
         DescribeOrderableDBInstanceOptionsPaginator,
+        DescribePendingMaintenanceActionsPaginator,
         DocDBClient,
     )
 
@@ -26,22 +31,32 @@ Usage::
     db_instance_available_waiter: DBInstanceAvailableWaiter = client.get_waiter("db_instance_available")
     db_instance_deleted_waiter: DBInstanceDeletedWaiter = client.get_waiter("db_instance_deleted")
 
+    describe_certificates_paginator: DescribeCertificatesPaginator = client.get_paginator("describe_certificates")
+    describe_db_cluster_parameter_groups_paginator: DescribeDBClusterParameterGroupsPaginator = client.get_paginator("describe_db_cluster_parameter_groups")
+    describe_db_cluster_parameters_paginator: DescribeDBClusterParametersPaginator = client.get_paginator("describe_db_cluster_parameters")
+    describe_db_cluster_snapshots_paginator: DescribeDBClusterSnapshotsPaginator = client.get_paginator("describe_db_cluster_snapshots")
     describe_db_clusters_paginator: DescribeDBClustersPaginator = client.get_paginator("describe_db_clusters")
     describe_db_engine_versions_paginator: DescribeDBEngineVersionsPaginator = client.get_paginator("describe_db_engine_versions")
     describe_db_instances_paginator: DescribeDBInstancesPaginator = client.get_paginator("describe_db_instances")
     describe_db_subnet_groups_paginator: DescribeDBSubnetGroupsPaginator = client.get_paginator("describe_db_subnet_groups")
     describe_events_paginator: DescribeEventsPaginator = client.get_paginator("describe_events")
     describe_orderable_db_instance_options_paginator: DescribeOrderableDBInstanceOptionsPaginator = client.get_paginator("describe_orderable_db_instance_options")
+    describe_pending_maintenance_actions_paginator: DescribePendingMaintenanceActionsPaginator = client.get_paginator("describe_pending_maintenance_actions")
     ```
 """
 from mypy_boto3_docdb.client import DocDBClient
 from mypy_boto3_docdb.paginator import (
+    DescribeCertificatesPaginator,
+    DescribeDBClusterParameterGroupsPaginator,
+    DescribeDBClusterParametersPaginator,
+    DescribeDBClusterSnapshotsPaginator,
     DescribeDBClustersPaginator,
     DescribeDBEngineVersionsPaginator,
     DescribeDBInstancesPaginator,
     DescribeDBSubnetGroupsPaginator,
     DescribeEventsPaginator,
     DescribeOrderableDBInstanceOptionsPaginator,
+    DescribePendingMaintenanceActionsPaginator,
 )
 from mypy_boto3_docdb.waiter import DBInstanceAvailableWaiter, DBInstanceDeletedWaiter
 
@@ -52,11 +67,16 @@ __all__ = (
     "Client",
     "DBInstanceAvailableWaiter",
     "DBInstanceDeletedWaiter",
+    "DescribeCertificatesPaginator",
+    "DescribeDBClusterParameterGroupsPaginator",
+    "DescribeDBClusterParametersPaginator",
+    "DescribeDBClusterSnapshotsPaginator",
     "DescribeDBClustersPaginator",
     "DescribeDBEngineVersionsPaginator",
     "DescribeDBInstancesPaginator",
     "DescribeDBSubnetGroupsPaginator",
     "DescribeEventsPaginator",
     "DescribeOrderableDBInstanceOptionsPaginator",
+    "DescribePendingMaintenanceActionsPaginator",
     "DocDBClient",
 )
